@@ -1,6 +1,13 @@
 
-import os,json,multiprocessing
-from .file import File
+import os,json,multiprocessing,threading
+try:
+    from file import File
+except BaseException:
+    pass
+try:
+    from .file import File
+except BaseException:
+    pass
 
 class Download:
     def __init__(self,version):
@@ -27,7 +34,7 @@ class Download:
         except BaseException as e:
             pass
 
-        file.File(self.dic['url'],minecraft_dir+f'\\versions\\{name}\\{name}.json')
+        File(self.dic['url'],minecraft_dir+f'\\versions\\{name}\\{name}.json')
     def download_core_jar(self,name,minecraft_dir):
         url = json.load(open(minecraft_dir+f'\\versions\\{name}\\{name}.json'))['downloads']['client']['url']
         File(url,minecraft_dir+f'\\versions\\{name}\\{name}.jar')
@@ -39,7 +46,7 @@ class Download:
 
         asset = json.load(open(f'{minecraft_dir}\\assets\\indexes\\{dic["assets"]}.json'))
         process = multiprocessing.Process(target=self.download_assets_core,args=[asset,name,minecraft_dir])
-        process.start()
+        process.run()
     def download_assets_core(self,asset,name,minecraft_dir):
         for i in asset['objects'].values():
             try:
@@ -53,7 +60,7 @@ class Download:
         for i in libs:
             thread = multiprocessing.Process(target=self.download_core,args=[i,name,minecraft_dir])
 
-            thread.start()
+            thread.run()
 
 
 
@@ -91,10 +98,10 @@ class Download:
         except BaseException as e:
             print(e)
     def main(self,name,minecraft_dir):
-        test.download_version_json(name,minecraft_dir)
-        test.download_core_jar(name,minecraft_dir)
-        test.download_assets(name,minecraft_dir)
-        test.download_lib(name,minecraft_dir)
+        self.download_version_json(name,minecraft_dir)
+        self.download_core_jar(name,minecraft_dir)
+        self.download_assets(name,minecraft_dir)
+        self.download_lib(name,minecraft_dir)
 
 
 
