@@ -1,6 +1,5 @@
 
-
-import json,os,threading
+import json ,os ,threading
 try:
     from file import File
 except BaseException:
@@ -16,18 +15,25 @@ except BaseException:
     pass
 
 class server:
-    def __init__(self,version):
+    def __init__(self ,version):
         self.version = version
-    def load(self):
+
         try:
 
             os.mkdir(r'C:\Users\Default\AppData\Roaming\.mcl')
         except BaseException as e:
             pass
         self.basepath = r'C:\Users\Default\AppData\Roaming\.mcl'
-        File('https://launchermeta.mojang.com/mc/game/version_manifest.json',self.basepath+'\\versions.json')
+        File('https://launchermeta.mojang.com/mc/game/version_manifest.json' ,self.basepat h +'\\versions.json')
+        self.aa = '<html><body>Sorry, invalid request</body></html>'
 
-        with open(self.basepath+'\\versions.json') as f:
+        with open(self.basepat h +'\\versions.json') as f:
+            self.content = f.read()
+
+        with open(self.basepat h +'\\versions.json' ,'w') as f:
+            f.write(self.content.replace(self.aa ,''))
+
+        with open(self.basepat h +'\\versions.json') as f:
             self.content = f.read()
 
         for i in eval(self.content)['versions']:
@@ -37,23 +43,41 @@ class server:
                 return
         raise SystemError(''
                           'This version does not exist.')
-    def download_server_core_jar(self,dir):
+    def download_server_core_jar(self ,dir):
         File(self.dic['url'], dir + '\\server.json')
-        self.ser = json.load(open(dir + '\\server.json'))
+        with open(dir + '\\server.json') as f:
+            self.content = f.read()
+        for i in range(10):
+
+            with open(dir + '\\server.json' ,'w') as f:
+                f.write(self.content.replace(self.aa ,''))
+        with open(dir + '\\server.json', 'w') as f:
+            f.write(self.content.replace('true', 'True'))
+        with open(dir + '\\server.json', 'w') as f:
+            f.write(self.content.replace(self.aa, ''))
+
+
+
+        with open(dir + '\\server.json') as f:
+            a = f.read()
+
+
+        self.ser = eval(a)
+
         while True:
 
             try:
 
-                File(self.ser['downloads']['server']['url'],dir+'\\server.jar')
+                File(self.ser['downloads']['server']['url'] ,di r +'\\server.jar')
                 break
             except BaseException as e:
                 print(e)
                 continue
 
-    def setting_default(self,di):
-        with open(di+'\\eula.txt','w') as f:
+    def setting_default(self ,di):
+        with open(d i +'\\eula.txt' ,'w') as f:
             f.write('eula=true')
-        with open(di+'\\server.properties','a') as f:
+        with open(d i +'\\server.properties' ,'a') as f:
             f.write('')
         self.setting_add(di, 'allow-flight', 'false')
         self.setting_add(di, 'allow-nether', 'true')
@@ -107,8 +131,8 @@ class server:
         self.setting_add(di, 'view-distance', '10')
         self.setting_add(di, 'white-list', 'false')
 
-    def setting_add(self,dir,a,b):
-        with open(dir+'\\server.properties') as f:
+    def setting_add(self ,dir ,a ,b):
+        with open(di r +'\\server.properties') as f:
             self.d = f.read()
 
 
@@ -121,22 +145,22 @@ class server:
 
         final = self.format.encode(ad)
 
-        with open(dir+'\\server.properties','w') as f:
+        with open(di r +'\\server.properties' ,'w') as f:
             f.write(final)
-    def start_thread(self,java,di):
-        server_thread = threading.Thread(target=self.start,args=[java,di])
+    def start_thread(self ,java ,di):
+        server_thread = threading.Thread(target=self.start ,args=[java ,di])
         server_thread.start()
         server_thread.join()
 
-    def start(self,java,di):
+    def start(self ,java ,di):
         os.chdir(di)
-        jar_path = di+'\\server.jar'
+        jar_path = d i +'\\server.jar'
         os.system(f'{java} -jar {jar_path}')
-    def main(self,dir,java):
-        self.load()
+    def main(self ,dir ,java):
+
         self.download_server_core_jar(dir)
         self.setting_default(dir)
-        self.start_thread(java,dir)
+        self.start_thread(java ,dir)
 
 
 if __name__ == '__main__':
@@ -145,7 +169,7 @@ if __name__ == '__main__':
     a.download_server_core_jar("D:\\test")
     a.setting_default("D:\\test")
 
-    a.start('java',"D:\\test")
+    a.start('java' ,"D:\\test")
 
 
 
